@@ -3,6 +3,7 @@ from typing import Dict, List, Optional
 
 from gql import gql
 
+from ..utils.folder_functions import check_folder_path
 from .gql_queries import *
 
 
@@ -11,38 +12,53 @@ class Projects:
         self.saagie_api = saagie_api
 
     @staticmethod
-    def __create_groupe_role(params: Dict, group: str, role: str) -> Dict:
+    def __map_role(role: str) -> str:
         """
-        Create a dict with the group and role to add to the project
-        Parameters
+        Map role with valid Saagie Role
         ----------
-        params:Dict
-            Dict of parameters to create the role
-        group : str
-            Authorization management: name of the group to add the given role to
-        role : str
-            Authorization management: role to give to the given group on the project
+        params:role:str
+            Role as simple string
         Returns
         -------
-        Dict
-            Dict that contains the authorized group and role
+        str
+            Valid Saagie role
         """
-        if role:
-            if role == "Manager":
-                role = "ROLE_PROJECT_MANAGER"
-            elif role == "Editor":
-                role = "ROLE_PROJECT_EDITOR"
-            elif role == "Viewer":
-                role = "ROLE_PROJECT_VIEWER"
-            else:
-                raise ValueError("❌ 'role' takes value in ('Manager', 'Editor'," " 'Viewer')")
+        if role.lower() in ("manager", "editor", "viewer"):
+            return f"ROLE_PROJECT_{role.upper()}"
+        raise ValueError("❌ 'role' takes value in ('Manager', 'Editor'," " 'Viewer')")
+
+    @staticmethod
+    def _create_groupe_role(
+        params: Dict,
+        group: Optional[str],
+        role: Optional[str],
+        groups_and_roles: Optional[List[Dict]],
+    ) -> Dict:
+
+        if groups_and_roles and (group or role):
+            raise RuntimeError(
+                "❌ Too many arguments, specify either a group and role, "
+                "or multiple groups and roles with groups_and_roles"
+            )
+
+        if groups_and_roles:
+            group_block = [
+                {"name": g, "role": Projects.__map_role(r)} for mydict in groups_and_roles for g, r in mydict.items()
+            ]
 
-        # Set group permission
-        if group is not None:
-            group_block = [{"name": group, "role": role}]
             params["authorizedGroups"] = group_block
+            return params
 
-        return params
+        if group and role:
+            saagie_role = Projects.__map_role(role)
+            group_block = [{"name": group, "role": saagie_role}]
+            params["authorizedGroups"] = group_block
+            return params
+
+        raise RuntimeError(
+            "❌ Too few arguments, specify either a group and role, "
+            "or multiple groups and roles with groups_and_roles"
+        )
 
     def list(self, pprint_result: Optional[bool] = None) -> Dict:
         """Get information for all projects (id, name, creator, description,
@@ -150,7 +166,8 @@ class Projects:
         self,
         name: str,
         group: str = None,
-        role: str = "Manager",
+        role: str = None,
+        groups_and_roles: Optional[List[Dict]] = None,
         description: str = "",
         jobs_technologies_allowed: Dict = None,
         apps_technologies_allowed: Dict = None,
@@ -162,10 +179,8 @@ class Projects:
         ----------
         name : str
             Name of the project (must not already exist)
-        group : None or str, optional
-            Authorization management: name of the group to add the given role to
-        role : str, optional
-            Authorization management: role to give to the given group on the project
+        groups_and_roles:list[dict], optional
+            dict of groups and their respective roles on the project
         description : str, optional
             Description of the project
         jobs_technologies_allowed:list, optional
@@ -185,7 +200,7 @@ class Projects:
         """
         # Create the params of the query
         params = {"name": name}
-        params = self.__create_groupe_role(params, group, role)
+        params = self._create_groupe_role(params, group, role, groups_and_roles)
         if description:
             params["description"] = description
 
@@ -287,6 +302,7 @@ class Projects:
         name: str = None,
         group: str = None,
         role: str = None,
+        groups_and_roles: Optional[List[Dict]] = None,
         description: str = None,
         jobs_technologies_allowed: Dict = None,
         apps_technologies_allowed: Dict = None,
@@ -302,11 +318,13 @@ class Projects:
             Name of the project
             If not filled, defaults to current value, else it will change the job's name
         group : None or str, optional
-            Authorization management: name of the group to add the given role to
-            If not filled, defaults to current value, else it will change the group
+            Authorization management: name of the group to add the given role to,
+            cannot be set if groups_and_roles is already set
         role : str, optional
             Authorization management: role to give to the given group on the project
-            If not filled, defaults to current value, else it will change the role
+            cannot be set if groups_and_roles is already set
+        groups_and_roles:list[dict], optional
+            dict of groups and their respective roles on the project, cannot be set if group or role are already set
         description : str, optional
             Description of the project
             If not filled, defaults to current value, else it will change the job's description
@@ -329,7 +347,7 @@ class Projects:
         """
         params = {"projectId": project_id}
         previous_project_version = self.get_info(project_id)["project"]
-        params = self.__create_groupe_role(params, group, role)
+        params = self._create_groupe_role(params, group, role, groups_and_roles)
 
         if not group and not role:
             params["authorizedGroups"] = [
@@ -382,3 +400,101 @@ class Projects:
         )
         logging.info("✅ Project [%s] successfully deleted", project_id)
         return result
+
+    def export(
+        self,
+        project_id: str,
+        output_folder: str,
+        error_folder: Optional[str] = "",
+        versions_limit: Optional[int] = None,
+        versions_only_current: bool = False,
+        project_only_env_vars: bool = False,
+    ) -> bool:
+        """Export the project in a folder
+
+        Parameters
+        ----------
+        project_id : str
+            Project ID
+        output_folder : str
+            Path to store the exported project
+        error_folder : str, optional
+            Path to store the non exported job/app/pipeline ID in case of error. If not set, error is not write
+        versions_limit : int, optional
+            Maximum limit of versions to fetch per job/app/pipeline. Fetch from most recent
+            to the oldest
+        versions_only_current : bool, optional
+            Whether to only fetch the current version of each job/app/pipeline
+        project_only_env_vars : bool, optional
+            True if only project environment variable should be exported False otherwise
+        Returns
+        -------
+        bool
+            True if project is successfully exported False otherwise
+        """
+
+        result = True
+        output_folder = check_folder_path(output_folder)
+        output_folder += project_id + "/"
+        output_folder_job = output_folder + "jobs/"
+        output_folder_pipeline = output_folder + "pipelines/"
+        output_folder_app = output_folder + "apps/"
+        output_folder_env_vars = output_folder + "env_vars/"
+        list_jobs = self.saagie_api.jobs.list_for_project_minimal(project_id)
+        id_jobs = [job["id"] for job in list_jobs["jobs"]]
+
+        list_pipelines = self.saagie_api.pipelines.list_for_project_minimal(project_id)["project"]
+        id_pipelines = [pipeline["id"] for pipeline in list_pipelines["pipelines"]]
+
+        list_apps = self.saagie_api.apps.list_for_project_minimal(project_id)
+        id_apps = [app["id"] for app in list_apps["labWebApps"]]
+
+        job_failed = []
+        pipeline_failed = []
+        app_failed = []
+        env_var_failed = []
+
+        env_vars_export = self.saagie_api.env_vars.export(
+            project_id, output_folder_env_vars, error_folder=error_folder, project_only=project_only_env_vars
+        )
+        if not env_vars_export:
+            env_var_failed.append(project_id)
+
+        for id_job in id_jobs:
+            job_export = self.saagie_api.jobs.export(
+                id_job,
+                output_folder_job,
+                error_folder=error_folder,
+                versions_limit=versions_limit,
+                versions_only_current=versions_only_current,
+            )
+            if not job_export:
+                job_failed.append(id_job)
+
+        for id_pipeline in id_pipelines:
+            pipeline_export = self.saagie_api.pipelines.export(
+                id_pipeline,
+                output_folder_pipeline,
+                error_folder=error_folder,
+                versions_limit=versions_limit,
+                versions_only_current=versions_only_current,
+            )
+            if not pipeline_export:
+                pipeline_failed.append(id_pipeline)
+
+        for id_app in id_apps:
+            app_export = self.saagie_api.apps.export(
+                id_app,
+                output_folder_app,
+                error_folder=error_folder,
+                versions_limit=versions_limit,
+                versions_only_current=versions_only_current,
+            )
+            if not app_export:
+                app_failed.append(id_app)
+        if job_failed or pipeline_failed or app_failed or env_var_failed:
+            result = False
+            logging.warning("❌ Project [%s] has not been successfully exported", project_id)
+        else:
+            logging.info("✅ Project [%s] successfully exported", project_id)
+        return result
